/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@users.sf.net>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2004 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.util;

import org.apache.regexp.*;

public class IPv4Util
{
  /*--------------------------------------------------------------------------------
   * Static data members
   *--------------------------------------------------------------------------------
   */

  public static final long MAX_ADDRESS = 0xFFFFFFFFL;

  private static final REProgram IPV4_PATTERN;

  /*--------------------------------------------------------------------------------
   * Constructors
   *--------------------------------------------------------------------------------
   */

  public IPv4Util()
  { // only present for bean-like environments - do not construct this object directly
  } // end constructor

  /*--------------------------------------------------------------------------------
   * External static operations
   *--------------------------------------------------------------------------------
   */

  public static final boolean isValid(String ip_addr)
  {
    if (ip_addr==null)
      return false;
    RE matcher = new RE(IPV4_PATTERN);
    if (!matcher.match(ip_addr))
      return false;
    for (int i=1; i<=4; i++)
    { // parse long integers, assemble into return value
      int val = Integer.parseInt(matcher.getParen(i));
      if ((val<0) || (val>255))
	return false;

    } // end for

    return true;

  } // end isValid

  public static final long stringToLongAddress(String ip_addr) throws IllegalArgumentException
  {
    RE matcher = new RE(IPV4_PATTERN);
    if (!(matcher.match(ip_addr)))
      throw new IllegalArgumentException("invalid IP address: " + ip_addr);
    long rc = 0;
    for (int i=1; i<=4; i++)
    { // parse long integers, assemble into return value
      long val = Long.parseLong(matcher.getParen(i));
      if ((val<0) || (val>255))
	throw new IllegalArgumentException("invalid IP address: " + ip_addr);
      rc = (rc << 8) | val;

    } // end for

    return rc;

  } // end stringToLongAddress

  public static final String longToStringAddress(long addr) throws IllegalArgumentException
  {
    if ((addr<0) || (addr>MAX_ADDRESS))
      throw new IllegalArgumentException("invalid IP address: " + addr);
    StringBuffer rc = new StringBuffer(16);
    for (int i=0; i<4; i++)
    { // build string representation from the right up
      rc.insert(0,addr & 0xFFL);
      rc.insert(0,'.');
      addr >>= 8;

    } // end for

    rc.delete(0,1);
    return rc.toString();
    
  } // end longToStringAddress

  /*--------------------------------------------------------------------------------
   * Static initializer
   *--------------------------------------------------------------------------------
   */

  static
  {
    try
    { // compile the pattern
      RECompiler comp = new RECompiler();
      IPV4_PATTERN = comp.compile("^\\s*(\\d{1,3})\\.(\\d{1,3})\\.(\\d{1,3})\\.(\\d{1,3})\\s*$");

    } // end try
    catch (RESyntaxException e)
    { // shouldn't happen
      throw new Error(e.getMessage());

    } // end catch

  } // end static initializer

} // end class IPv4Util
