/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@users.sf.net>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001-2004 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.core;

import java.util.List;
import java.util.Locale;
import java.util.TimeZone;
import com.silverwrist.venice.except.AccessError;
import com.silverwrist.venice.except.DataException;
import com.silverwrist.venice.except.EmailException;

public interface UserContext extends SearchMode
{
  public int getUID();

  public String getUserName();

  public int getContactID();

  public String getDescription();

  public boolean isLoggedIn();

  public boolean isEmailVerified();

  public void authenticate(String username, String password) throws AccessError, DataException;

  public void confirmEmail(int conf_num) throws AccessError, DataException;

  public void resendEmailConfirmation() throws DataException, EmailException;

  public ContactInfo getContactInfo() throws DataException;

  public boolean putContactInfo(ContactInfo ci) throws DataException, EmailException;

  public UserProfile getProfile(String xusername) throws DataException;

  public UserProfile getProfile(int xuid) throws DataException;

  public void setPassword(String password, String reminder) throws DataException;

  public void setDescription(String new_descr) throws DataException;

  public List getMemberCommunities() throws DataException;

  public CommunityContext getCommunityContext(int cid) throws DataException;

  public CommunityContext getCommunityContext(String alias) throws DataException;

  public List getRootCategoryList() throws DataException;

  public CategoryDescriptor getCategoryDescriptor(int catid) throws DataException;

  public List searchForCommunities(int field, int mode, String term, int offset, int count)
      throws DataException;

  public int getSearchCommunityCount(int field, int mode, String term) throws DataException;

  public List getCommunitiesInCategory(int catid, int offset, int count) throws DataException;

  public List getCommunitiesInCategory(CategoryDescriptor cat, int offset, int count)
      throws DataException;

  public int getNumCommunitiesInCategory(int catid) throws DataException;

  public int getNumCommunitiesInCategory(CategoryDescriptor cat) throws DataException;

  public List searchForCategories(int mode, String term, int offset, int count) throws DataException;

  public int getSearchCategoryCount(int mode, String term) throws DataException;

  public CommunityContext createCommunity(String name, String alias, String language, String synopsis,
					  String rules, String joinkey, CommunityHideMode hide_mode)
      throws DataException, AccessError;

  public boolean canCreateCommunity();

  public List getSideBoxList() throws DataException;

  public void addSideBox(int id) throws DataException;

  public List getConferenceHotlist() throws DataException;

  public boolean hasAdminAccess();

  public AdminOperations getAdminInterface() throws AccessError;

  public Locale getLocale() throws DataException;

  public void setLocale(Locale locale) throws DataException;

  public TimeZone getTimeZone() throws DataException;

  public void setTimeZone(TimeZone timezone) throws DataException;

  public String getAuthenticationToken() throws AccessError, DataException;

  public boolean authenticateWithToken(String token) throws DataException;

  public Advertisement selectAd();

  public boolean displayPostPictures() throws DataException;

  public UserProperties getProperties() throws DataException;

  public void setProperties(UserProperties props) throws DataException;

  public boolean canSetUserPhoto() throws DataException;

  public List searchPosts(String search_terms, int offset, int count) throws DataException;

  public int getSearchPostCount(String search_terms) throws DataException;

  public java.sql.Date getDateOfBirth();

  public void setDateOfBirth(java.sql.Date date) throws DataException;

  public void authenticatePrivileged(String username) throws AccessError, DataException;

} // end interface UserContext

