/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@users.sf.net>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001-2006 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.core.internals;

import java.sql.Connection;
import java.sql.SQLException;
import java.util.List;
import org.apache.log4j.Logger;
import com.silverwrist.venice.core.SecurityInfo;
import com.silverwrist.venice.db.*;
import com.silverwrist.venice.except.AccessError;
import com.silverwrist.venice.htmlcheck.HTMLChecker;
import com.silverwrist.venice.security.*;
import com.silverwrist.venice.svc.GlobalSite;
import com.silverwrist.venice.svc.ServiceControl;
import com.silverwrist.venice.util.MailSend;

public class EnvEngine
{
  /*--------------------------------------------------------------------------------
   * Static data members
   *--------------------------------------------------------------------------------
   */

  /** Instance of {@link org.apache.log4j.Logger Logger} for this class. */
  private static final Logger logger = Logger.getLogger(EnvEngine.class);

  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private GlobalSite globalsite;      // the global site
  private EngineBackend engine;       // the engine
  private ServiceControl scon;        // the service controller

  /*--------------------------------------------------------------------------------
   * Constructors
   *--------------------------------------------------------------------------------
   */

  public EnvEngine(GlobalSite globalsite, EngineBackend engine, ServiceControl scon)
  {
    this.globalsite = globalsite;
    this.engine = engine;
    this.scon = scon;

  } // end constructor

  protected EnvEngine(EnvEngine other)
  {
    this.globalsite = other.globalsite;
    this.engine = other.engine;
    this.scon = other.scon;

  } // end constructor

  /*--------------------------------------------------------------------------------
   * Internal operations
   *--------------------------------------------------------------------------------
   */

  protected SecurityMonitor getStaticMonitor()
  {
    return (SecurityMonitor)(globalsite.queryService(SecurityMonitor.class));

  } // end getStaticMonitor

  /*--------------------------------------------------------------------------------
   * External operations
   *--------------------------------------------------------------------------------
   */

  public final GlobalSite getGlobalSite()
  {
    return globalsite;

  } // end getGlobalSite

  public final EngineBackend getEngine()
  {
    return engine;

  } // end getEngine

  public final ServiceControl getSCM()
  {
    return scon;

  } // end getSCM

  public final Connection getConnection() throws SQLException
  {
    return globalsite.getConnection(null);

  } // end getConnection

  public final boolean permissionDefined(String symbol, boolean no_follow)
  {
    return getStaticMonitor().permissionDefined(symbol,no_follow);

  } // end permissionDefined

  public final List getRoleList(String symbol)
  {
    return getStaticMonitor().getRoleList(symbol);

  } // end getRoleList

  public final Role getRole(String symbol)
  {
    return getStaticMonitor().getRole(symbol);

  } // end getRole

  public final Role getRoleForLevel(int level)
  {
    return getStaticMonitor().getRoleForLevel(level);

  } // end getRoleForLevel

  public final Role getDefaultRole(String symbol)
  {
    return getStaticMonitor().getDefaultRole(symbol);

  } // end getDefaultRole

  public final SecurityInfo getSecurityInfo()
  {
    return new SecurityInfoWrapper(getStaticMonitor());

  } // end getSecurityInfo

  public final String getStockMessage(String key)
  {
    return globalsite.getStockMessage(key);

  } // end getStockMessage

  public final MailSend getMailSender()
  {
    return (MailSend)(globalsite.queryService(MailSend.class));

  } // end getMailSender

  public final HTMLChecker getHTMLChecker(String id)
  {
    return (HTMLChecker)(globalsite.queryService(HTMLChecker.class,id));

  } // end getHTMLChecker

} // end class EnvEngine
