/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Community System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@users.sf.net>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001-2004 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.htmlcheck.filters;

import java.util.*;
import org.apache.log4j.Logger;
import org.apache.regexp.*;
import com.silverwrist.util.*;
import com.silverwrist.venice.htmlcheck.Rewriter;
import com.silverwrist.venice.htmlcheck.RewriterServices;
import com.silverwrist.venice.htmlcheck.MarkupData;

public class EmailRewriter implements Rewriter
{
  /*--------------------------------------------------------------------------------
   * Static data members
   *--------------------------------------------------------------------------------
   */

  private static Logger logger = Logger.getLogger(EmailRewriter.class);

  private static REProgram s_match = null;

  /*--------------------------------------------------------------------------------
   * Constructor
   *--------------------------------------------------------------------------------
   */

  public EmailRewriter()
  { // do nothing
  } // end constructor

  /*--------------------------------------------------------------------------------
   * Implementations from interface Rewriter
   *--------------------------------------------------------------------------------
   */

  public String getName()
  {
    return null;

  } // end getName

  public MarkupData rewrite(String data, RewriterServices svc)
  {
    RE m = new RE(s_match,RE.MATCH_CASEINDEPENDENT);
    if (!(m.match(data)))
      return null;  // not a valid E-mail address

    // build the <A> tag (the gnarliest part)
    StringBuffer open_a = new StringBuffer("<a href=\"mailto:");
    open_a.append(data).append("\"");
    String catenate = svc.getRewriterAttrValue("ANCHORTAIL");
    if (!(StringUtil.isStringEmpty(catenate)))
      open_a.append(' ').append(catenate);
    open_a.append('>');

    // return the markup data back to the checker
    return new MarkupData(open_a.toString(),data,"</a>");

  } // end rewrite

  /*--------------------------------------------------------------------------------
   * Static initializer
   *--------------------------------------------------------------------------------
   */

  static
  {
    try
    { // compile our regular expression
      RECompiler compiler = new RECompiler();
      s_match = compiler.compile("^[A-Za-z0-9!#$%*+-/=?^_`{|}~.]+@[A-Za-z0-9_-]+(?:\\.[A-Za-z0-9_-]+)+$");

    } // end try
    catch (RESyntaxException e)
    { // shouldn't happen
      logger.fatal("caught RESyntaxException in EmailRewriter initializer",e);

    } // end catch

  } // end static initializer

} // end class EmailRewriter
