/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@users.sf.net>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001-2004 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.ui.jsp;

import java.io.IOException;
import javax.servlet.jsp.*;
import javax.servlet.jsp.tagext.*;
import com.silverwrist.venice.ui.*;
import com.silverwrist.venice.ui.helpers.ResourceLoader;
import com.silverwrist.venice.ui.menus.MenuComponent;
import com.silverwrist.venice.ui.menus.MenuTemplate;

public class FrameLeftMenuTag extends VeniceTagSupport
{
  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private String m_name = null;

  /*--------------------------------------------------------------------------------
   * Overrides from class TagSupport
   *--------------------------------------------------------------------------------
   */

  public int doStartTag() throws JspException
  {
    if (m_name==null)
      throw new JspTagException("<frame:leftmenu/> tag without name= attribute!");
    RequestInput ri = getRequestInput();
    MenuComponent mc = ri.getMenu(m_name);
    if (mc==null)
      throw new JspTagException("<frame:leftmenu/> menu name= not defined!");

    ResourceLoader rload = (ResourceLoader)(ri.queryService(ResourceLoader.class));
    MenuTemplate templ = rload.getMenuTemplate("left");
    if (templ==null)
      throw new JspTagException("internal error: \"left\" menu template not defined!");

    try
    { // write out what we came here to accomplish
      JspWriter out = pageContext.getOut();
      mc.render(getRequestOutput(),out,templ);

    } // end try
    catch (IOException e)
    { // convert the I/O error into something the servlet engine can deal with
      throw new JspTagException("error writing left menu - " + e.getMessage());

    } // end catch

    return SKIP_BODY;

  } // end doStartTag

  public void release()
  {
    super.release();
    m_name = null;

  } // end release

  /*--------------------------------------------------------------------------------
   * Attribute set functions
   *--------------------------------------------------------------------------------
   */

  public void setName(String s)
  {
    m_name = s;

  } // end setName

} // end class FrameLeftMenuTag
