/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@users.sf.net>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001-2004 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.ui.jsp;

import java.io.IOException;
import java.net.URLEncoder;
import javax.servlet.jsp.*;
import javax.servlet.jsp.tagext.*;
import com.silverwrist.util.StringUtil;
import com.silverwrist.venice.ui.*;
import com.silverwrist.venice.ui.helpers.HTMLRendering;

public class UtilXLinkTag extends VeniceBodyTagSupport
{
  /*--------------------------------------------------------------------------------
   * Static data members
   *--------------------------------------------------------------------------------
   */

  private static final String LOCATION_PARAM = "${location}";

  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private String m_href = null;
  private int m_type = -1;
  private String m_class = null;
  private String m_target = null;
  private String m_text = null;
  private String m_title = null;
  private boolean m_target_external = false;

  /*--------------------------------------------------------------------------------
   * Overrides from class BodyTagSupport
   *--------------------------------------------------------------------------------
   */

  public int doStartTag()
  {
    return EVAL_BODY_BUFFERED;

  } // end doStartTag

  public int doAfterBody()
  {
    return SKIP_BODY;

  } // end doAfterBody

  public int doEndTag() throws JspException
  {
    // Do some shorts-checking on our stored data.
    if (m_href==null)
      throw new JspTagException("<util:xlink/> does not have a <util:href/>!");
    if (m_type<0)
      throw new JspTagException("<util:xlink/> does not have a <util:href/>!");
    if (m_text==null)
      throw new JspTagException("<util:xlink/> does not have a <util:text/>!");

    // Dig out the RequestInput and HTMLRendering service.
    RequestInput ri = getRequestInput();
    HTMLRendering html = (HTMLRendering)(ri.queryService(HTMLRendering.class));

    try
    { // Do parameter replacement on the HREF string if necessary.
      if (m_href.indexOf(LOCATION_PARAM)>=0)
	m_href = StringUtil.replaceAllInstances(m_href,LOCATION_PARAM,URLEncoder.encode(ri.getLocation(),"UTF-8"));

      // write out what we came here to accomplish
      JspWriter out = pageContext.getOut();
      out.write("<a ");
      if (m_class!=null)
	out.write("class=\"" + m_class + "\" ");
      out.write("href=\"" + html.formatURL(m_href,m_type) + "\"");
      if (m_title!=null)
	out.write(" title=\"" + m_title + "\"");
      if (m_target!=null)
	out.write(" target=\"" + m_target + "\"");
      out.write(">" + m_text + "</a>");

    } // end try
    catch (IOException e)
    { // convert the I/O error into something the servlet engine can deal with
      throw new JspTagException("error writing <a/> tag - " + e.getMessage());

    } // end catch

    m_href = null;
    m_type = -1;
    m_text = null;
    m_title = null;
    if (m_target_external)
      m_target = null;
    m_target_external = false;
    return EVAL_PAGE;

  } // end doEndTag

  public void release()
  {
    super.release();
    m_class = null;
    m_target = null;

  } // end release

  /*--------------------------------------------------------------------------------
   * Attribute set functions
   *--------------------------------------------------------------------------------
   */

  public void setAclass(String s)
  {
    m_class = s;

  } // end setAclass

  public void setTarget(String s)
  {
    m_target = s;

  } // end setTarget

  /*--------------------------------------------------------------------------------
   * External operations
   *--------------------------------------------------------------------------------
   */

  final void setLink(String href, int type)
  {
    m_href = href;
    m_type = type;

  } // end setLink

  final void setText(String text)
  {
    m_text = text;

  } // end setText

  final void setTitle(String title)
  {
    m_title = title;

  } // end setTitle

  final void setTarget2(String s)
  {
    if (m_target==null)
    { // set target via external tag
      m_target = s;
      m_target_external = true;

    } // end if

  } // end setTarget2

} // end class UtilXLinkTag
