/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@users.sf.net>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001-2004 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.ui.menus;

import java.io.*;
import java.util.Set;
import org.w3c.dom.*;
import com.silverwrist.util.DOMElementHelper;
import com.silverwrist.venice.ui.RequestOutput;

class HeaderItem implements MenuComponent
{
  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private TextItem m_subitem;

  /*--------------------------------------------------------------------------------
   * Constructor
   *--------------------------------------------------------------------------------
   */

  HeaderItem(Element elt)
  {
    DOMElementHelper h = new DOMElementHelper(elt);
    m_subitem = new TextItem(h.getElementText());

  } // end constructor

  /*--------------------------------------------------------------------------------
   * Implementations from interface MenuComponent
   *--------------------------------------------------------------------------------
   */

  public void render(RequestOutput out, Writer wr, MenuTemplate template, Set defines) throws IOException
  {
    // Render the subitem first.
    StringWriter subwr = new StringWriter();
    m_subitem.render(out,subwr,template,defines);
    subwr.flush();

    // Now render this as a header.
    if (wr==null)
      wr = out.getWriter();
    template.renderItem(wr,"header",subwr.toString(),null);

  } // end render

  public void render(RequestOutput out, Writer wr, MenuTemplate template) throws IOException
  {
    this.render(out,wr,template,java.util.Collections.EMPTY_SET);

  } // end render

  public String getTitle(RequestOutput out)
  {
    return null;

  } // end getTitle

} // end class HeaderItem
