/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@users.sf.net>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2002 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.ui.rpc;

import java.util.*;
import com.silverwrist.venice.ui.*;

public class XmlRpcTestHandler implements XmlRpcDispatch
{
  /*--------------------------------------------------------------------------------
   * Constructor
   *--------------------------------------------------------------------------------
   */

  public XmlRpcTestHandler()
  { // do nothing
  } // end constructor

  /*--------------------------------------------------------------------------------
   * Implementations from interface XmlRpcDispatch
   *--------------------------------------------------------------------------------
   */

  public Object dispatch(RequestInput req, XmlRpcRequest xreq, Map environment) throws Exception, XmlRpcFault
  {
    if (xreq.getMethod().equals("venice:test.sumDifference"))
    { // do the sumdifference API
      if (xreq.getParamCount()!=2)
	throw new XmlRpcFault(XmlRpcFault.INVALID_PARAMS,"parameter count mismatch");

      Integer n1, n2;
      try
      { // cast parameters to Integer
	n1 = (Integer)(xreq.getParam(0));
	n2 = (Integer)(xreq.getParam(1));

      } // end try
      catch (ClassCastException e)
      { // class cast exception!
	throw new XmlRpcFault(XmlRpcFault.INVALID_PARAMS,"parameter type mismatch");

      } // end catch

      HashMap rc = new HashMap();
      rc.put("sum",new Integer(n1.intValue() + n2.intValue()));
      rc.put("difference",new Integer(n1.intValue() - n2.intValue()));
      return rc;

    } // end if

    return null;

  } // end dispatch

} // end class XmlRpcTestHandler
