/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@users.sf.net>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001-2006 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.ui.servlet;

import java.io.*;
import java.net.URLEncoder;
import javax.servlet.http.HttpServletResponse;
import org.apache.log4j.Logger;
import com.silverwrist.venice.core.*;
import com.silverwrist.venice.except.*;
import com.silverwrist.venice.ui.*;
import com.silverwrist.venice.ui.helpers.*;
import com.silverwrist.venice.ui.view.*;

public class GatewayServlet extends BaseServlet
{
  /*--------------------------------------------------------------------------------
   * Static data members
   *--------------------------------------------------------------------------------
   */

  /** Instance of {@link org.apache.log4j.Logger Logger} for this class. */
  private static final Logger logger = Logger.getLogger(GatewayServlet.class);

  /*--------------------------------------------------------------------------------
   * Implementations from class BaseServlet
   *--------------------------------------------------------------------------------
   */

  public Object process(RequestInput req)
  {
    try
    { // look up the servet we wanna bounce to and try to go there
      String target = req.getQueryString();
      if (target==null)
	return new HTTPError(HttpServletResponse.SC_BAD_REQUEST,"no parameter specified");
      if (logger.isDebugEnabled())
	logger.debug("they want to redirect to: " + target);
      if (req.getUser().isLoggedIn())
	return new Redirect(target,LinkTypes.ABSOLUTE);
      else
	return new Redirect("login.js.vs?tgt=" + URLEncoder.encode(target,"UTF-8"),LinkTypes.SERVLET);

    } // end try
    catch (UnsupportedEncodingException e)
    { // shouldn't happen
      return new HTTPError(HttpServletResponse.SC_INTERNAL_SERVER_ERROR,"internal error: " + e.toString());

    } // end catch

  } // end process

} // end class GatewayServlet
