/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@users.sf.net>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001-2006 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.ui.servlet;

import java.io.*;
import org.apache.log4j.Logger;
import com.silverwrist.venice.ui.*;
import com.silverwrist.venice.ui.helpers.*;
import com.silverwrist.venice.ui.script.*;

public class UserServlet extends BaseServlet
{
  /*--------------------------------------------------------------------------------
   * Static data members
   *--------------------------------------------------------------------------------
   */

  /** Instance of {@link org.apache.log4j.Logger Logger} for this class. */
  private static final Logger logger = Logger.getLogger(UserServlet.class);

  /** The name of the script to be executed. */
  private static final String SCRIPT_EXEC = "showuser.js";

  /*--------------------------------------------------------------------------------
   * Implementations from class BaseServlet
   *--------------------------------------------------------------------------------
   */

  public Object process(RequestInput req) throws Exception, ThrowableContent
  {
    String uname = req.getPathInfo().substring(1);  // the username we're looking at
    req.setRequestAttribute("username",uname);

    // Set up to execute a script to handle this request.
    ScriptSupport ssup = (ScriptSupport)(req.queryService(ScriptSupport.class));
    String script_file = ssup.getScriptName(SCRIPT_EXEC);
    String logger_name = ssup.getScriptLoggerName(SCRIPT_EXEC);
    if (logger.isDebugEnabled())
      logger.debug("EXECUTING " + script_file);

    ScriptManager smgr = (ScriptManager)(req.queryService(ScriptManager.class));
    ScriptReturn sro = new ScriptReturn();
    smgr.exec(new File(script_file),logger_name,sro);
    return sro.get();

  } // end process

} // end class UserServlet
