/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@users.sf.net>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2004 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.ui.velocity;

import com.silverwrist.venice.ui.*;
import com.silverwrist.venice.ui.helpers.*;

public class StdObject
{
  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private RequestOutput m_rout;
  private HTMLRendering m_html = null;

  /*--------------------------------------------------------------------------------
   * Constructor
   *--------------------------------------------------------------------------------
   */

  StdObject(RequestOutput out)
  {
    m_rout = out;

  } // end constructor

  /*--------------------------------------------------------------------------------
   * External operations
   *--------------------------------------------------------------------------------
   */

  public String formatURL(String url, String type)
  {
    if (m_html==null)
      m_html = (HTMLRendering)(m_rout.queryService(HTMLRendering.class));
    return m_html.formatURL(url,type);

  } // end formatURL

  public String fontTag(String color, String size)
  {
    if (m_html==null)
      m_html = (HTMLRendering)(m_rout.queryService(HTMLRendering.class));
    return m_html.getFontTag(color.trim(),size.trim());

  } // end fontTag

  public String externalStatic(String path)
  {
    if (m_html==null)
      m_html = (HTMLRendering)(m_rout.queryService(HTMLRendering.class));
    return m_html.getExternalStaticPath(path);

  } // end externalStatic

  public String button(String id, String type)
  {
    if (m_html==null)
      m_html = (HTMLRendering)(m_rout.queryService(HTMLRendering.class));
    id = id.trim().toLowerCase();
    type = type.trim().toLowerCase();
    if (type.equals("visual"))
      return m_html.getButtonVisual(id);
    else if (type.equals("input"))
      return m_html.getButtonInput(id);
    else
      return "";

  } // end button

  public String comment(String data)
  {
    if (m_html==null)
      m_html = (HTMLRendering)(m_rout.queryService(HTMLRendering.class));
    if (m_html.useHTMLComments())
      return "<!-- " + data + " -->";
    else
      return "";

  } // end comment

} // end class StdObject
