/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@users.sf.net>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2004 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.ui.velocity;

import java.util.Collection;

/**
 * Common interface for all output objects that supply parameters to Velocity.
 *
 * @author Eric J. Bowersox &lt;erbo@users.sf.net&gt;
 * @version X
 */
public interface VelocitySupplyParams
{
  /**
   * Returns the value of a parameter set on the object.
   *
   * @param key The name of the parameter to look up.
   * @return The parameter's value, or <code>null</code> if the parameter was not set.
   */
  public Object getParameter(String key);

  /**
   * Returns a <code>java.util.Collection</code> of all parameter names currently defined on this object.
   *
   * @return A collection of all parameter names currently defined.
   */
  public Collection getParameterNames();

} // end interface VelocitySupplyParams
