/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@users.sf.net>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2002 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.util;

/**
 * An interface that is implemented by objects that wish to provide data values as read-only properties.
 *
 * @author Eric J. Bowersox &lt;erbo@users.sf.net&gt;
 * @version X
 */
public interface PropertyProvider
{
  /**
   * Queries this object for a specified property value.  All properties can be expressed as strings.
   *
   * @param identifier The property of the object that should be returned.
   * @return The string value of the property.
   * @exception com.silverwrist.venice.except.PropertyNotFoundException If no such property is available in
   *            the specified class.
   */
  public abstract String propGet(String identifier);

  /**
   * Queries this object for a specified property value as an integer.
   *
   * @param identifier The property of the object that should be returned.
   * @return The integer value of the property.
   * @exception com.silverwrist.venice.except.PropertyNotFoundException If no such property is available in
   *            the specified class, or the value cannot be expressed as an integer.
   */
  public abstract int propGetInt(String identifier);

  /**
   * Queries this object for a specified property value as a Boolean.
   *
   * @param identifier The property of the object that should be returned.
   * @return The Boolean value of the property.
   * @exception com.silverwrist.venice.except.PropertyNotFoundException If no such property is available in
   *            the specified class, or the value cannot be expressed as a Boolean.
   */
  public abstract boolean propGetBoolean(String identifier);

} // end interface PropertyProvider
